Programa base para la tarjeta STM32-MINIMO, usando la libreria mbed-dev.

Dependencies:   mbed-dev

Fork of STM32F103C8T6_Hello by Zoltan Hudak

Revision:
11:7ad02c61c1f9
Parent:
10:4b88be251088
--- a/main.cpp	Thu Sep 15 18:40:03 2016 +0000
+++ b/main.cpp	Mon Dec 19 15:26:09 2016 +0000
@@ -1,20 +1,19 @@
-#include "stm32f103c8t6.h"
+
 #include "mbed.h"
-  
-int main() {
-    confSysClock();     //Configure system clock (72MHz HSE clock, 48MHz USB clock)
-    
-    Serial      pc(PA_2, PA_3);
-    DigitalOut  myled(LED1);
-    
-    while(1) {
-        // The on-board LED is connected, via a resistor, to +3.3V (not to GND). 
-        // So to turn the LED on or off we have to set it to 0 or 1 respectively
-        myled = 0;      // turn the LED on
-        wait_ms(200);   // 200 millisecond
-        myled = 1;      // turn the LED off
-        wait_ms(1000);  // 1000 millisecond
-        pc.printf("Blink\r\n");
-    }
+
+Serial     pc(PA_9, PA_10);
+DigitalOut myled(PC_13);
+
+int main()
+{
+ProgMain:
+// The on-board LED is connected, via a resistor, to +3.3V (not to GND). 
+// So to turn the LED on or off we have to set it to 0 or 1 respectively
+myled = false;  // turn the LED on
+wait_ms(100);   // 100 millisecond
+myled = true;   // turn the LED off
+wait_ms(100);  // 100 millisecond
+pc.printf("Blink\r\n");
+goto ProgMain;
+
 }
- 
\ No newline at end of file